@@ -39,8 +39,7 @@
 #import <objc/runtime.h>
 #import <Carbon/Carbon.h>
 
-using mozilla::plugins::PluginModuleChild;
-using mozilla::plugins::AssertPluginThread;
+using namespace mozilla::plugins;
 
 namespace mac_plugin_interposing {
 
@@ -545,7 +544,7 @@ void NSCursorInfo::SetCustomImageData(uint8_t* aData, uint32_t aDataLength)
 bool NSCursorInfo::GetNativeCursorsSupported()
 {
   if (mNativeCursorsSupported == -1) {
-    AssertPluginThread();
+    ENSURE_PLUGIN_THREAD(false);
     PluginModuleChild *pmc = PluginModuleChild::current();
     if (pmc) {
       bool result = pmc->GetNativeCursorsSupported();
@@ -690,7 +689,7 @@ void FocusPluginProcess() {
 
 void NotifyBrowserOfPluginShowWindow(uint32_t window_id, CGRect bounds,
                                      bool modal) {
-  AssertPluginThread();
+  ENSURE_PLUGIN_THREAD_VOID();
 
   PluginModuleChild *pmc = PluginModuleChild::current();
   if (pmc)
@@ -698,7 +697,7 @@ void NotifyBrowserOfPluginShowWindow(uint32_t window_id, CGRect bounds,
 }
 
 void NotifyBrowserOfPluginHideWindow(uint32_t window_id, CGRect bounds) {
-  AssertPluginThread();
+  ENSURE_PLUGIN_THREAD_VOID();
 
   PluginModuleChild *pmc = PluginModuleChild::current();
   if (pmc)
@@ -707,7 +706,7 @@ void NotifyBrowserOfPluginHideWindow(uint32_t window_id, CGRect bounds) {
 
 void NotifyBrowserOfSetCursor(NSCursorInfo& aCursorInfo)
 {
-  AssertPluginThread();
+  ENSURE_PLUGIN_THREAD_VOID();
   PluginModuleChild *pmc = PluginModuleChild::current();
   if (pmc) {
     pmc->SetCursor(aCursorInfo);
@@ -716,7 +715,7 @@ void NotifyBrowserOfSetCursor(NSCursorInfo& aCursorInfo)
 
 void NotifyBrowserOfShowCursor(bool show)
 {
-  AssertPluginThread();
+  ENSURE_PLUGIN_THREAD_VOID();
   PluginModuleChild *pmc = PluginModuleChild::current();
   if (pmc) {
     pmc->ShowCursor(show);
@@ -725,7 +724,7 @@ void NotifyBrowserOfShowCursor(bool show)
 
 void NotifyBrowserOfPushCursor(NSCursorInfo& aCursorInfo)
 {
-  AssertPluginThread();
+  ENSURE_PLUGIN_THREAD_VOID();
   PluginModuleChild *pmc = PluginModuleChild::current();
   if (pmc) {
     pmc->PushCursor(aCursorInfo);
@@ -734,7 +733,7 @@ void NotifyBrowserOfPushCursor(NSCursorInfo& aCursorInfo)
 
 void NotifyBrowserOfPopCursor()
 {
-  AssertPluginThread();
+  ENSURE_PLUGIN_THREAD_VOID();
   PluginModuleChild *pmc = PluginModuleChild::current();
   if (pmc) {
     pmc->PopCursor();
