@@ -334,14 +334,14 @@ MacroAssemblerPPC::linkParallelExitFrame(const Register &reg) {
 }
 
 void
-MacroAssemblerPPC::handleFailureWithHandler(void *handler) {
+MacroAssemblerPPC::handleFailureWithHandlerTail(void *handler) {
 	ispew("handleFailureWithHandler");
 	// Call an ABI-compliant handler function, reserving adequate space
 	// on the stack for a non-ABI compliant exception frame which we will
 	// then analyse.
 
 	// ResumeFromException is defined in IonFrames.h
-	int size = (sizeof(ResumeFromException) + 16) & ~16;
+	int size = (sizeof(ResumeFromException) + 16) & ~15;
 	x_subi(stackPointerRegister, stackPointerRegister, size);
 	x_mr(r3, stackPointerRegister);
 
@@ -349,13 +349,6 @@ MacroAssemblerPPC::handleFailureWithHandler(void *handler) {
 	passABIArg(r3);
 	callWithABI(handler);
 	
-	JitCode *excTail =
-		GetIonContext()->runtime->jitRuntime()->getExceptionTail();
-	b(excTail);
-}
-
-void
-MacroAssemblerPPC::handleFailureWithHandlerTail() {
 	Label entryFrame;
 	Label catch_;
 	Label finally;
@@ -852,8 +845,11 @@ MacroAssemblerPPC::cmp32Set(Assembler::Condition cond, Register lhs, Register rh
         adde(dest, r12, r0);
     } else {
         // Use the emitSet branched version as a slow path for any condition.
-        // Since cmp32 implies a signed comparison, use cmpw.
-        cmpw(lhs, rhs);
+	if (PPC_USE_UNSIGNED_COMPARE(cond)) {
+        	cmplw(lhs, rhs);
+	} else {
+        	cmpw(lhs, rhs);
+	}
         emitSet(cond, dest);
     }
 }
@@ -873,8 +869,8 @@ MacroAssemblerPPC::cmpPtrSet(Assembler::Condition cond, const Register &lhs,
     } else {
 	// This is an unsigned comparison, so use cmplw and the
 	// long form emitSet.
-       	cmplw(lhs, rhs);
-       	emitSet(cond, dest);
+	cmplw(lhs, rhs);
+	emitSet(cond, dest);
     }
 }
 
